@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """PKI methods module."""
+from hvac import utils
 from hvac.api.vault_api_base import VaultApiBase
 
 DEFAULT_MOUNT_POINT = 'pki'
@@ -25,7 +26,7 @@ class Pki(VaultApiBase):
         :return: The certificate as pem.
         :rtype: str
         """
-        api_path = '/v1/{mount_point}/ca/pem'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/ca/pem', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -44,7 +45,7 @@ class Pki(VaultApiBase):
         :return: The certificate chain as pem.
         :rtype: str
         """
-        api_path = '/v1/{mount_point}/ca_chain'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/ca_chain', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -65,7 +66,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/cert/{serial}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/cert/{serial}',
             mount_point=mount_point,
             serial=serial,
         )
@@ -87,7 +89,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/certs'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/certs', mount_point=mount_point)
         response = self._adapter.list(
             url=api_path,
         )
@@ -109,7 +111,7 @@ class Pki(VaultApiBase):
         params = {
                 'pem_bundle': pem_bundle,
                 }
-        api_path = '/v1/{mount_point}/config/ca'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/ca', mount_point=mount_point)
         return self._adapter.post(
             url=api_path,
             json=params,
@@ -128,7 +130,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/config/crl'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/crl', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -149,7 +151,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/config/crl'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/crl', mount_point=mount_point)
         params = extra_params
         if expiry is not None:
             params['expiry'] = expiry
@@ -174,7 +176,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/config/urls'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/urls', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -195,7 +197,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/config/urls'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/urls', mount_point=mount_point)
         return self._adapter.post(
             url=api_path,
             json=params,
@@ -214,7 +216,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/config/crl'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/config/crl', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -233,7 +235,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/crl/rotate'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/crl/rotate', mount_point=mount_point)
         response = self._adapter.get(
             url=api_path,
         )
@@ -258,7 +260,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/intermediate/generate/{type}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/intermediate/generate/{type}',
             mount_point=mount_point,
             type=type,
         )
@@ -286,7 +289,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/intermediate/set-signed'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/intermediate/set-signed',
             mount_point=mount_point,
         )
 
@@ -317,7 +321,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/issue/{name}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/issue/{name}',
             mount_point=mount_point,
             name=name,
         )
@@ -345,7 +350,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/revoke'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/revoke', mount_point=mount_point)
 
         params = {}
         params['serial_number'] = serial_number
@@ -372,7 +377,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rname: requests.Response
         """
-        api_path = '/v1/{mount_point}/roles/{name}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/roles/{name}',
             mount_point=mount_point,
             name=name,
         )
@@ -400,7 +406,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/roles/{name}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/roles/{name}',
             mount_point=mount_point,
             name=name,
         )
@@ -422,7 +429,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        api_path = '/v1/{mount_point}/roles'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/roles', mount_point=mount_point)
         response = self._adapter.list(
             url=api_path,
         )
@@ -443,7 +450,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rname: requests.Response
         """
-        api_path = '/v1/{mount_point}/roles/{name}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/roles/{name}',
             mount_point=mount_point,
             name=name,
         )
@@ -471,7 +479,8 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/root/generate/{type}'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/root/generate/{type}',
             mount_point=mount_point,
             type=type,
         )
@@ -497,9 +506,9 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/root'.format(
+        api_path = utils.format_url(
+            '/v1/{mount_point}/root',
             mount_point=mount_point,
-            type=type,
         )
 
         return self._adapter.delete(
@@ -525,7 +534,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/root/sign-intermediate'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/root/sign-intermediate', mount_point=mount_point)
 
         params = extra_params
         params['csr'] = csr
@@ -551,7 +560,7 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/root/sign-self-issued'.format(mount_point=mount_point)
+        api_path = utils.format_url('/v1/{mount_point}/root/sign-self-issued', mount_point=mount_point)
 
         params = {}
         params['certificate'] = certificate
@@ -582,10 +591,11 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/sign/{name}'.format(
-                mount_point=mount_point,
-                name=name,
-                )
+        api_path = utils.format_url(
+            '/v1/{mount_point}/sign/{name}',
+            mount_point=mount_point,
+            name=name,
+        )
 
         params = extra_params
         params['csr'] = csr
@@ -619,10 +629,11 @@ class Pki(VaultApiBase):
         if name:
             url_to_transform = url_to_transform + '/{name}'
 
-        api_path = url_to_transform.format(
-                mount_point=mount_point,
-                name=name,
-                )
+        api_path = utils.format_url(
+            url_to_transform,
+            mount_point=mount_point,
+            name=name,
+        )
 
         params = extra_params
         params['csr'] = csr
@@ -648,9 +659,10 @@ class Pki(VaultApiBase):
         :return: The JSON response of the request.
         :rtype: requests.Response
         """
-        api_path = '/v1/{mount_point}/tidy'.format(
-                mount_point=mount_point,
-                )
+        api_path = utils.format_url(
+            '/v1/{mount_point}/tidy',
+            mount_point=mount_point,
+        )
 
         params = extra_params
 
