@@ -3,12 +3,14 @@ import logging
 
 from hvac.api.system_backend.audit import Audit
 from hvac.api.system_backend.auth import Auth
+from hvac.api.system_backend.capabilities import Capabilities
 from hvac.api.system_backend.health import Health
 from hvac.api.system_backend.init import Init
 from hvac.api.system_backend.key import Key
 from hvac.api.system_backend.leader import Leader
 from hvac.api.system_backend.lease import Lease
 from hvac.api.system_backend.mount import Mount
+from hvac.api.system_backend.namespace import Namespace
 from hvac.api.system_backend.policy import Policy
 from hvac.api.system_backend.seal import Seal
 from hvac.api.system_backend.wrapping import Wrapping
@@ -18,12 +20,14 @@ from hvac.api.vault_api_category import VaultApiCategory
 __all__ = (
     'Audit',
     'Auth',
+    'Capabilities',
     'Health',
     'Init',
     'Key',
     'Leader',
     'Lease',
     'Mount',
+    'Namespace',
     'Policy',
     'Seal',
     'SystemBackend',
@@ -35,16 +39,19 @@ __all__ = (
 logger = logging.getLogger(__name__)
 
 
-class SystemBackend(VaultApiCategory, Audit, Auth, Health, Init, Key, Leader, Lease, Mount, Policy, Seal, Wrapping):
+class SystemBackend(VaultApiCategory, Audit, Auth, Capabilities, Health, Init, Key, Leader, Lease, Mount, Namespace,
+                    Policy, Seal, Wrapping):
     implemented_classes = [
         Audit,
         Auth,
+        Capabilities,
         Health,
         Init,
         Key,
         Leader,
         Lease,
         Mount,
+        Namespace,
         Policy,
         Seal,
         Wrapping,
